<?php
if ( ! defined( 'ABSPATH' ) ) {
	die();
}

use AcyMailing\Classes\UserClass;
use AcyMailing\Classes\ListClass;

/**
 * Class Forminator_Acymailing_Connector_Plugin
 */
class Forminator_Acymailing_Connector_Plugin {


	/**
	 * Forminator_Acymailing_Connector_Plugin constructor.
	 */
	public function __construct() {
		log_me('---------------------------------- add new AcyMailing subscription');


	}

	public function isValidForm($formdata, $form_id) {
		if ($formdata->form_id != $form_id) {

			#echo 'Please check the Form ID in the settings of the Forminator-AcyMailing-Connector Plugin';
			log_me('ERROR: Please check the Form ID in the settings of the Forminator-AcyMailing-Connector Plugin!!!!!!');
			return false;
		}
		log_me('Successfully validated form data');
		return true;

	}
	/**
	 * @param $field_data_array
	 * @param $formdata
	 *
	 * @return mixed
	 */
	public function get_formdata_action($field_data_array, $formdata) {


		// add time and language
		$formdata->timestamp                    = time();
		$formdata->date                         = date('Y-m-d', $formdata->timestamp);
		$formdata->time                         = date('H:i:s', $formdata->timestamp);
		$formdata->date_de                      = date("d.m.Y", $formdata->timestamp );
		$formdata->date_en                      = date("Y-m-d", $formdata->timestamp );
		$formdata->date_en_short                = date("Ymd", $formdata->timestamp );
		$formdata->timeshort                    = date("His" );
		$formdata->language                     = 'de';

		// add the form submission data

		foreach($field_data_array as $field_data)
		{
			switch ($field_data['name'])
			{
				case($formdata->name_token):
					$formdata->name = sanitize_text_field($field_data['value']);
					break;
				case($formdata->email_token):
					$formdata->email = sanitize_email($field_data['value']);
					break;
				/*case($formdata->privacy_token):
					$formdata->privacy = $field_data['value'];
					break;*/
			}

		}
		return $formdata;
	}

	/**
	 * @param $formdata
	 */
	public function add_to_acym_list_action( $formdata ) {
		$this->add2Acymailing ($formdata);
	}

	/**
	 * Add the data to AcyMailing
	 *
	 * @param $formdata stdClass
	 *
	 * @return bool|void
	 * @see https://docs.acymailing.com/developers/acymailing-developer-documentation#code-api-for-quick-integration
	 */
	public static function add2Acymailing ($formdata) {
		log_me('Go to subscribe new Acymailing User');

		$myUser = new stdClass();

		$myUser->email = $formdata->email;
		$myUser->name = $formdata->name; //this information is optional
		$customFields = [];
		#$customFields[3] = $formdata->language; // the custom field id can be found in the Custom fields list of the AcyMailing admin page

		#$userClass = acym_get('class.user');
		$userClass = new UserClass();
		#$listClass = acym_get('class.list');
		$listClass = new ListClass();

		$user = $userClass->getOneByEmail($myUser->email);

		if ($user != null)
		{
			// Get subscription
			log_me('UPDATE Acymailing user ID : ' . $user->id. ' and mail: '. $user->email);
			$userSubscriptions = $userClass->getUserSubscriptionById($user->id);
			$is_sent_welcome = false;
			foreach($userSubscriptions as $subscription)
			{
				if ($formdata->acy_list_resent_welcome != null && $formdata->acy_list_resent_welcome > 0 && $subscription->id == $formdata->acy_list_resent_welcome) {
					$is_sent_welcome = true;
				}
				log_me('user is alredy subscribed to list ID ' . $subscription->id . ', '.$subscription->name);
			}

			// make sure the user data gets updated
			$myUser->id = $user->id; // make sure to add the user ID here as well, otherwise no update of useredata
			$userId = $userClass->save($myUser, $customFields);

			// make sure the user subscribed to all the lists
			if(!empty($formdata->lists))
			{
				log_me('Go to subsribe user to the follwing list(s): '.serialize($formdata->lists));
				$userClass->subscribe($user->id, $formdata->lists);
				log_me('Successfully subscribed user!');

			}
			log_me('Updated user fields with ID: '.$userId);
			if ($is_sent_welcome) {
				$userClass->unsubscribe($userId, $formdata->acy_list_resent_welcome);
				log_me('Unsubscribed user ID '.$userId.' from list ID '.$formdata->acy_list_resent_welcome);
				$userClass->subscribe($userId, $formdata->acy_list_resent_welcome);
				log_me('(Re)subscribed user ID '.$userId.' to list ID '.$formdata->acy_list_resent_welcome);
			}
		} else {
			$userId = $userClass->save($myUser, $customFields); // this function will return you the ID of the user inserted in the AcyMailing table
			log_me('ADDED new Acymailing user with ID: '.$userId);

			log_me('Go to subsribe user to the follwing list(s): '.serialize($formdata->lists));

			//$unsubscribe = array(); // Id of the lists you want the user to be unsubscribe from (can be empty)
			$acyUserId = $userId; // you can use the previous example code to get the user by its site user id or its email address

			//$userClass = acym_get('class.user');
			$userClass = new UserClass();

			if(!empty($formdata->lists)){
				$userClass->subscribe($acyUserId, $formdata->lists);
				log_me('Successfully subscribed user!');

			}
			/*
			if(!empty($remove)){
				$userClass->unsubscribe($acyUserId, $unsubscribe);
				log_me('Successfully unsubscribed user!');
			}*/
		}
	}
}

?>