<?php
/*
Plugin Name: Forminator AcyMailing Connector
Plugin URI: https://www.netzsinn.de/wordpress-plugn-forminator-acymailing-connector
Description: Adds Data from Forminator form into a AcyMailing list
Version: 1.2.9
Author: Bernhard Woehrlin, NetzSinn.de
Author URI: https://www.netzsinn.de
License. GPLv2
Domain Path: /languages
*/
/**
 * MAKE SURE TO SET THE ACYMAILING LIST PARAMETER IN THE add_forminator_acym_plugin function!!!
 *
 */
if ( ! defined( 'ABSPATH' ) ) {
	die();
}

// load AcyMailing classes
if(!include_once(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.'acymailing'.DIRECTORY_SEPARATOR.'back'.DIRECTORY_SEPARATOR.'helpers'.DIRECTORY_SEPARATOR.'helper.php')){
	echo 'This code can not work without the AcyMailing Component';
	return false;
}
use AcyMailing\Classes\UserClass;

if (is_admin()) {
	require_once dirname(__FILE__) . '/admin/admin.php';
}

require_once dirname(__FILE__) . '/includes/class-helper.inc.php';
require_once dirname(__FILE__) . '/includes/class-connector.inc.php';

require_once dirname(__FILE__) . '/includes/plugin-update-checker-4.10/plugin-update-checker.php';
$myUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
	'https://www.netzsinn.de/extensions/wordpress-plugins/netzsinn-acymailing-forminator-plugin.json',
	__FILE__, //Full path to the main plugin file or functions.php.
	'netzsinn-acymailing-forminator-plugin-slug'
);

// Make sure the code gets just called, if Forminator is active
add_action( 'forminator_loaded', 'forminator_acym_plugin' );

/**
 * This should get called, if Forminator is active
 */
function forminator_acym_plugin() {

	error_log( 'forminator acymailing plugin initialized ------------------------------ ' );
	$forminator_acymailing_connector_options = get_option( 'forminator_acymailing_connector_option_name' );
	$forminator_form_id = $forminator_acymailing_connector_options['field_0']; // you will find the ID if you copy the shortcode of the form
	$module = Forminator_API::get_form( $forminator_form_id );
	
	if ($forminator_form_id === $module->id) {

		// This is the $field_data_array and the $form_id of the form
		add_action( 'forminator_custom_form_submit_field_data', 'add_forminator_acym_plugin', 10, 2 );
		
		// Will fire if you have set Behaviour > Method to Page Reload
		#add_action( 'forminator_custom_form_after_handle_submit', 'add_forminator_acym_plugin', 10, 2);
		
		// Will fire if you have set Submission Behaviour > Method to Ajax
		#add_action( 'forminator_custom_form_after_save_entry', 'add_forminator_acym_plugin', 11, 2 );
	}
	
}

/**
 * - reads in the Plugin parameters
 * - reads in the Forminator form data
 * - connects to AcyMailing
 *
 * @param $field_data_array
 * @param $form_id
 */
function add_forminator_acym_plugin($field_data_array, $form_id) {

	$forminator_acymailing_connector_options = get_option( 'forminator_acymailing_connector_option_name' );
	#print_r ($forminator_acymailing_connector_options);
	$formdata = new stdClass();

	$formdata->form_id = $forminator_acymailing_connector_options['field_0']; // you will find the ID if you copy the shortcode of the form
	$formdata->lists = explode(',',$forminator_acymailing_connector_options['field_1']); // add the list ids of all lists you like the user subscribe to. check acymailing for existing lists
	$formdata->acy_list_resent_welcome = $forminator_acymailing_connector_options['field_2']; // add a id of a list, if you like that a user gets the welcome message, even if he is already subscribed.
	$formdata->name_token = $forminator_acymailing_connector_options['field_3']; // name of the Name field
	$formdata->email_token = $forminator_acymailing_connector_options['field_4']; // name of the Email field
	// add more fields, if you want to store them in AcyMail add code in add2Acymailing();
	//$formdata->privacy_token = 'gdprcheckbox-1'; // name of the Checkbox field; not really necessary if not saved in AcyMailing
	#$formdata->myfield = '';

	$plugin = new Forminator_Acymailing_Connector_Plugin();
	error_log( 'formdata->form_id: '.$formdata->form_id );
	error_log( 'form_id: '.$form_id );
	if($plugin->isValidForm($formdata, $form_id) === true)
	{
		$formdata = $plugin->get_formdata_action($field_data_array, $formdata);
		$plugin->add_to_acym_list_action($formdata);

	} else {
		// do nothing else 
	}

}


